@@ -1,7 +1,7 @@
 
 /*
  *  autogen.c
- *  $Id: autogen.c,v 1.31 2002/06/08 20:43:25 bkorb Exp $
+ *  $Id: autogen.c,v 1.33 2002/09/20 04:56:44 bkorb Exp $
  *  This is the main routine for autogen.
  */
 
@@ -32,7 +32,9 @@
 
 tSCC zSchemeInit[] =
 "(add-hook! before-error-hook error-source-line)\n"
+
 "(define header-file \"\")  (define header-guard \"\")\n"
+
 "(define (make-header-guard hdr-pfx)\n"
 "   (begin\n"
 "      (set! header-file  (out-name))\n"
@@ -41,9 +43,16 @@ tSCC zSchemeInit[] =
 "             \"_\" header-file \"_GUARD\" ))))\n"
 "      (sprintf \"#ifndef %1$s\\n#define %1$s\" header-guard)\n"
 ")  )\n"
+
 "(define autogen-version \"" AUTOGEN_VERSION "\")\n"
+
 "(define-macro (defined-as predicate symbol)\n"
-"  `(and (defined? ',symbol) (,predicate ,symbol)))";
+"  `(and (defined? ',symbol) (,predicate ,symbol)))"
+
+"(define html-escape-encode (lambda (str)\n"
+"    (string-substitute str\n"
+"          '(\"&\"      \"<\"     \">\")\n"
+"          '(\"&amp;\"  \"&lt;\"  \"&gt;\") )))";
 
 STATIC sigjmp_buf  abendJumpEnv;
 
@@ -307,9 +316,9 @@ signalSetup( void )
     atexit( &finalMemCheck );
     /* Set the snprintfv library's memory management function pointers
        to use AutoGen's debugging malloc. */
-    snv_malloc  = (snv_pointer(*)SNV_PARAMS((size_t)))ag_alloc;
-    snv_realloc = (snv_pointer(*)SNV_PARAMS((snv_pointer, size_t)))ag_realloc;
-    snv_free    = (void(*)SNV_PARAMS((snv_pointer)))ag_free;
+    snv_malloc  = (snv_pointer(*)SNV_PARAMS((size_t)))aopts_alloc;
+    snv_realloc = (snv_pointer(*)SNV_PARAMS((snv_pointer, size_t)))aopts_realloc;
+    snv_free    = (void(*)SNV_PARAMS((snv_pointer)))aopts_free;
 #endif
 
     sa.sa_flags   = 0;
