@@ -1,6 +1,6 @@
 
 /*
- *  $Id: defReduce.c,v 1.17 2002/06/15 19:21:54 bkorb Exp $
+ *  $Id: defReduce.c,v 1.18 2002/09/29 00:14:18 bkorb Exp $
  *  Parse Reduction processing routines
  */
 
@@ -121,9 +121,10 @@ addSibMacro(
         YYSTYPE  def,
         YYSTYPE  list )
 {
+    tDefEntry*  ret   = (tDefEntry*)list;
     tDefEntry*  pDef  = (tDefEntry*)def;
-    tDefEntry*  pScn  = (tDefEntry*)list;
-    tDefEntry** ppT   = (tDefEntry**)&list;
+    tDefEntry*  pScn  = ret;
+    tDefEntry** ppT   = &ret;
 
     for (;;) {
         if (strcmp( pDef->pzDefName, pScn->pzDefName ) == 0) {
@@ -140,7 +141,7 @@ addSibMacro(
             /*
              *  Link in the new head of the twin chain to the sibling list.
              *  If the twin list is the first sibling, then ppT points
-             *  to the "list" variable.  It will now be changed to return
+             *  to the return value.  It will now be changed to return
              *  the value we need to return (the new head).
              */
             pDef->pNext = pScn->pNext;
@@ -148,15 +149,17 @@ addSibMacro(
             *ppT = pDef;
 
             /*
-             *  Find the end of the twin list for the new eldest twin.
-             *  Do this by setting a pointer to the place where we have
-             *  to stash the pointer to the list.  (We are not saving it.)
+             *  pScn is now unlinked from the chains.  Walk down the list of
+             *  twins hanging off of the new definitions and tack it on there.
              */
             for (ppT  = &(pDef->pTwin);
                  *ppT != NULL;
                  ppT  = &((*ppT)->pTwin) )
                 ;
 
+            /*
+             *  "ppT" points to a NULL pointer.  Stash our twin list ptr there.
+             */
             *ppT = pScn;
             break;
         }
@@ -166,9 +169,8 @@ addSibMacro(
          *  THEN put the new entry at the start of the list
          */
         if (pScn->pNext == NULL) {
-
             pDef->pNext = (tDefEntry*)list;
-            list = def;
+            ret = (tDefEntry*)def;
             break;
         }
 
@@ -181,7 +183,7 @@ addSibMacro(
         pScn = pScn->pNext;
     }
 
-    return list;
+    return (YYSTYPE)ret;
 }
 
 
