@@ -1,6 +1,6 @@
 
 /*
- *  $Id: autoopts.c,v 2.47 2002/08/10 19:28:28 bkorb Exp $
+ *  $Id: autoopts.c,v 2.51 2002/10/12 18:07:51 bkorb Exp $
  *
  *  This file contains all of the routines that must be linked into
  *  an executable to use the generated option processing.  The optional
@@ -51,26 +51,7 @@
  * If you do not wish that, delete this exception notice.
  */
 
-#define __EXTENSIONS__
-#include <sys/types.h>
-#include <sys/param.h>
-#include <sys/stat.h>
-
-#include <ctype.h>
-#include <stdio.h>
-#include <stdlib.h>
-#include <unistd.h>
-#include <config.h>
-#include <string.h>
-#include <errno.h>
-
-#ifdef HAVE_LIBGEN
-#  include <libgen.h>
-#endif
-
-#include <streqv.h>
 #include "autoopts.h"
-#include "compat/compat.h"
 
 #ifndef HAVE_PATHFIND
 #  include "compat/pathfind.c"
@@ -84,6 +65,8 @@ tSCC zIllOptChr[]   = "%s: illegal option -- %c\n";
 tSCC zIllegal[]     = "illegal";
 tSCC zIllOptStr[]   = "%s: %s option -- %s\n";
 tSCC zAmbiguous[]   = "ambiguous";
+tSCC zOptArg[]      = "option argument";
+
 
 tSCC zOnlyOne[]     = "one %s%s option allowed\n";
 tSCC zAtMost[]      = "%4$d %1$s%s options allowed\n";
@@ -677,7 +660,7 @@ optionMakePath( pzBuf, bufSize, pzName, pzProgPath )
     }
 
     /*
-     *  IF the name starts with "$$", then it must start be "$$" or
+     *  IF the name starts with "$$", then it must be "$$" or
      *  it must start with "$$/".  In either event, replace the "$$"
      *  with the path to the executable and append a "/" character.
      */
@@ -685,6 +668,19 @@ optionMakePath( pzBuf, bufSize, pzName, pzProgPath )
         tCC*  pzPath;
         tCC*  pz;
 
+        switch (pzName[2]) {
+        case '/':
+        case NUL:
+            break;
+        default:
+            return AG_FALSE;
+        }
+
+        /*
+         *  See if the path is included in the program name.
+         *  If it is, we're done.  Otherwise, we have to hunt
+         *  for the program using "pathfind".
+         */
         if (strchr( pzProgPath, '/' ) != (char*)NULL)
             pzPath = pzProgPath;
         else {
@@ -1003,12 +999,14 @@ loadOptionLine( pOpts, pOS, pzLine, direction )
 
     case ARG_MAY:
         if (*pOS->pzOptArg == NUL)
-            pOS->pzOptArg = NULL;
+             pOS->pzOptArg = NULL;
+        else AGDUPSTR( pOS->pzOptArg, pOS->pzOptArg, zOptArg );
+        break;
 
     case ARG_MUST:
         if (*pOS->pzOptArg == NUL)
              pOS->pzOptArg = "";
-        else pOS->pzOptArg = strdup( pOS->pzOptArg );
+        else AGDUPSTR( pOS->pzOptArg, pOS->pzOptArg, zOptArg );
         break;
     }
 
@@ -1240,7 +1238,7 @@ doEnvPresets( pOpts, type )
             case ARG_MUST:
                 if (*st.pzOptArg == NUL)
                      st.pzOptArg = "";
-                else st.pzOptArg = strdup( st.pzOptArg );
+                else AGDUPSTR( st.pzOptArg, st.pzOptArg, zOptArg );
                 break;
 
             default: /* no argument allowed */
@@ -1533,8 +1531,9 @@ void optionLoadLine( pOpts, pzLine )
     tCC*       pzLine;
 {
     tOptState st = { NULL, OPTST_SET, TOPT_UNDEFINED, 0, NULL };
-    char* pz = strdup( pzLine );
+    char* pz = AGDUPSTR( pzLine, pzLine, "user option line" );
     loadOptionLine( pOpts, &st, pz, DIRECTION_PROCESS );
+    AGFREE( pz );
 }
 
 
