@@ -1,6 +1,6 @@
 
 /*
- *  usage.c  $Id: usage.c,v 3.3 2002/05/24 01:44:42 bkorb Exp $
+ *  usage.c  $Id: usage.c,v 2.26 2002/10/12 18:07:52 bkorb Exp $
  *
  *  This module implements the default usage procedure for
  *  Automated Options.  It may be overridden, of course.
@@ -49,8 +49,6 @@
  * If you do not wish that, delete this exception notice.
  */
 
-#include <compat/compat.h>
-
 #include "autoopts.h"
 
 tSCC zAlt[]        = "\t\t\t\t- an alternate for %s\n";
@@ -232,15 +230,15 @@ optionUsage( pOptions, exitCode )
              *  IF there are option conflicts or dependencies,
              *  THEN print them here.
              */
-            if (  (pOD->pOptMust != (int*)NULL)
-               || (pOD->pOptCant != (int*)NULL) ) {
+            if (  (pOD->pOptMust != NULL)
+               || (pOD->pOptCant != NULL) ) {
 
                 fputs( zTabHyp, fp );
 
                 /*
                  *  DEPENDENCIES:
                  */
-                if (pOD->pOptMust != (int*)NULL) {
+                if (pOD->pOptMust != NULL) {
                     const int* pOptNo = pOD->pOptMust;
 
                     fputs( zReqThese, fp );
@@ -251,14 +249,14 @@ optionUsage( pOptions, exitCode )
                             break;
                     }
 
-                    if (pOD->pOptCant != (int*)NULL)
+                    if (pOD->pOptCant != NULL)
                         fputs( zTabHypAnd, fp );
                 }
 
                 /*
                  *  CONFLICTS:
                  */
-                if (pOD->pOptCant != (int*)NULL) {
+                if (pOD->pOptCant != NULL) {
                     const int* pOptNo = pOD->pOptCant;
 
                     fputs( zProhib, fp );
@@ -275,7 +273,7 @@ optionUsage( pOptions, exitCode )
              *  IF there is a disablement string
              *  THEN print the disablement info
              */
-            if (pOD->pz_DisableName != (char*)NULL )
+            if (pOD->pz_DisableName != NULL )
                 fprintf( fp, zDis, pOD->pz_DisableName );
 
             /*
@@ -313,8 +311,8 @@ optionUsage( pOptions, exitCode )
              *  THEN advise that this option may not be preset.
              */
             if (  ((pOD->fOptState & OPTST_NO_INIT) != 0)
-               && (  (pOptions->papzHomeList != (const char**)NULL)
-                  || (pOptions->pzPROGNAME != (const char*)NULL)
+               && (  (pOptions->papzHomeList != NULL)
+                  || (pOptions->pzPROGNAME != NULL)
                )  )
 
                 fputs( zNoPreset, fp );
@@ -378,7 +376,7 @@ optionUsage( pOptions, exitCode )
             fputs( zNumberOpt, fp );
     }
 
-    if (pOptions->pzExplain != (char*)NULL)
+    if (pOptions->pzExplain != NULL)
         fputs( pOptions->pzExplain, fp );
 
     /*
@@ -392,7 +390,7 @@ optionUsage( pOptions, exitCode )
          *  Display all the places we look for RC files
          */
         printInitList( pOptions->papzHomeList, &initIntro,
-                       pOptions->pzRcName, pOptions->pzProgName );
+                       pOptions->pzRcName, pOptions->pzProgPath );
 
         /*
          *  Let the user know about environment variable settings
@@ -425,10 +423,14 @@ optionUsage( pOptions, exitCode )
         /*
          *  If there is a detail string, now is the time for that.
          */
-        if (pOptions->pzDetail != (char*)NULL)
+        if (pOptions->pzDetail != NULL)
             fputs( pOptions->pzDetail, fp );
     }
 
+    if (pOptions->pzBugAddr != NULL)
+        fprintf( fp, "\nplease send bug reports to:  %s\n",
+                 pOptions->pzBugAddr );
+
     exit( exitCode );
 }
 
@@ -451,7 +453,7 @@ printInitList( papz, pInitIntro, pzRc, pzPN )
     for (;;) {
         const char* pzPath = *(papz++);
 
-        if (pzPath == (char*)NULL)
+        if (pzPath == NULL)
             break;
 
         if (optionMakePath( zPath, sizeof( zPath ), pzPath, pzPN ))
